@@ -1,11 +1,14 @@
 import asyncio
 import time
+from http import HTTPStatus
+from pathlib import Path
 
 import aiohttp
-from aiohttp import ClientSession
+from aiofiles import open as aio_open
+from aiohttp import ClientSession, TCPConnector
 
 from pymax.exceptions import Error
-from pymax.files import File, Photo
+from pymax.files import File, Photo, Video
 from pymax.formatting import Formatting
 from pymax.interfaces import ClientProtocol
 from pymax.mixins.utils import MixinsUtils
@@ -27,6 +30,7 @@ from pymax.payloads import (
     SendMessagePayload,
     SendMessagePayloadMessage,
     UploadPayload,
+    VideoAttachPayload,
 )
 from pymax.static.constant import DEFAULT_TIMEOUT
 from pymax.static.enum import AttachType, Opcode
@@ -40,9 +44,12 @@ from pymax.types import (
 
 
 class MessageMixin(ClientProtocol):
+    CHUNK_SIZE = 6 * 1024 * 1024
+
     async def _upload_file(self, file: File) -> None | Attach:
         try:
             self.logger.info("Uploading file")
+
             payload = UploadPayload().model_dump(by_alias=True)
             data = await self._send_and_wait(
                 opcode=Opcode.FILE_UPLOAD,
@@ -57,47 +64,206 @@ class MessageMixin(ClientProtocol):
                 self.logger.error("No upload URL or file ID received")
                 return None
 
-            file_bytes = await file.read()
+            self.logger.debug("Got upload URL and file_id=%s", file_id)
+
+            if file.path:
+                file_size = Path(file.path).stat().st_size
+                self.logger.info(
+                    "File size from path: %.2f MB", file_size / (1024 * 1024)
+                )
+            else:
+                file_bytes = await file.read()
+                file_size = len(file_bytes)
+                self.logger.info(
+                    "File size from URL: %.2f MB", file_size / (1024 * 1024)
+                )
+
+            connector = TCPConnector(limit=0)
+            timeout = aiohttp.ClientTimeout(total=None, sock_read=None, sock_connect=30)
 
             headers = {
                 "Content-Disposition": f"attachment; filename={file.file_name}",
-                "Content-Range": f"0-{len(file_bytes) - 1}/{len(file_bytes)}",
+                "Content-Length": str(file_size),
+                "Content-Range": f"0-{file_size - 1}/{file_size}",
             }
 
             loop = asyncio.get_running_loop()
             fut: asyncio.Future[dict] = loop.create_future()
-            try:
-                self._file_upload_waiters[int(file_id)] = fut
-            except Exception:
-                self.logger.exception("Failed to register file upload waiter")
+            self._file_upload_waiters[int(file_id)] = fut
+
+            async def file_generator():
+                bytes_sent = 0
+                chunk_num = 0
+                self.logger.debug("Starting file streaming from: %s", file.path)
+                async with aio_open(file.path, "rb") as f:
+                    while True:
+                        chunk = await f.read(self.CHUNK_SIZE)
+                        if not chunk:
+                            self.logger.info(
+                                "File streaming complete: %d bytes in %d chunks",
+                                bytes_sent,
+                                chunk_num,
+                            )
+                            break
+
+                        yield chunk
+
+                        bytes_sent += len(chunk)
+                        chunk_num += 1
+                        if chunk_num % 10 == 0:
+                            self.logger.info(
+                                "Upload progress: %.1f MB in %d chunks",
+                                bytes_sent / (1024 * 1024),
+                                chunk_num,
+                            )
+                        if chunk_num % 4 == 0:
+                            await asyncio.sleep(0)
+
+            async def bytes_generator(b: bytes):
+                bytes_sent = 0
+                chunk_num = 0
+                for i in range(0, len(b), self.CHUNK_SIZE):
+                    chunk = b[i : i + self.CHUNK_SIZE]
+                    yield chunk
+                    bytes_sent += len(chunk)
+                    chunk_num += 1
+                    if chunk_num % 10 == 0:
+                        self.logger.info(
+                            "Upload progress: %.1f MB in %d chunks",
+                            bytes_sent / (1024 * 1024),
+                            chunk_num,
+                        )
+                    if chunk_num % 4 == 0:
+                        await asyncio.sleep(0)
+
+            if file.path:
+                data_to_send = file_generator()
+            else:
+                data_to_send = bytes_generator(file_bytes)
+
+            self.logger.info("Starting file upload: %s", file.file_name)
 
             async with (
-                ClientSession() as session,
-                session.post(
-                    url=url,
-                    headers=headers,
-                    data=file_bytes,
-                ) as response,
+                ClientSession(connector=connector, timeout=timeout) as session,
+                session.post(url=url, headers=headers, data=data_to_send) as response,
             ):
-                if response.status != 200:
-                    self.logger.error(f"Upload failed with status {response.status}")
-                    # cleanup waiter
+                self.logger.debug("Server response status: %d", response.status)
+                if response.status != HTTPStatus.OK:
+                    self.logger.error("Upload failed with status %s", response.status)
                     self._file_upload_waiters.pop(int(file_id), None)
                     return None
 
+                self.logger.debug(
+                    "File sent successfully. Waiting for server confirmation "
+                    "(timeout=%d seconds, fileId=%s)",
+                    DEFAULT_TIMEOUT,
+                    file_id,
+                )
                 try:
                     await asyncio.wait_for(fut, timeout=DEFAULT_TIMEOUT)
+                    self.logger.info(
+                        "File upload completed successfully (fileId=%s)", file_id
+                    )
                     return Attach(_type=AttachType.FILE, file_id=file_id)
                 except asyncio.TimeoutError:
-                    self.logger.error(
+                    self.logger.warning(
                         "Timed out waiting for file processing notification for fileId=%s",
                         file_id,
                     )
                     self._file_upload_waiters.pop(int(file_id), None)
                     return None
-        except Exception as e:
-            self.logger.exception("Upload file failed: %s", str(e))
-            return None
+
+        except Exception:
+            self.logger.exception("Upload file failed")
+            raise
+
+    async def _upload_video(self, video: Video) -> None | Attach:
+        try:
+            self.logger.info("Uploading video")
+            payload = UploadPayload().model_dump(by_alias=True)
+            data = await self._send_and_wait(
+                opcode=Opcode.VIDEO_UPLOAD,
+                payload=payload,
+            )
+
+            if data.get("payload", {}).get("error"):
+                MixinsUtils.handle_error(data)
+
+            url = data.get("payload", {}).get("info", [None])[0].get("url", None)
+            video_id = (
+                data.get("payload", {}).get("info", [None])[0].get("videoId", None)
+            )
+            if not url or not video_id:
+                self.logger.error("No upload URL or video ID received")
+                return None
+
+            token = data.get("payload", {}).get("info", [None])[0].get("token", None)
+            if not token:
+                self.logger.error("No upload token received")
+                return None
+
+            file_bytes = await video.read()
+            file_size = len(file_bytes)
+
+            # Настройки для ClientSession
+            connector = TCPConnector(limit=0)
+            timeout = aiohttp.ClientTimeout(
+                total=900, sock_read=60
+            )  # 15 минут на видео
+
+            headers = {
+                "Content-Disposition": f"attachment; filename={video.file_name}",
+                "Content-Range": f"0-{file_size - 1}/{file_size}",
+                "Content-Length": str(file_size),
+                "Connection": "keep-alive",
+            }
+
+            loop = asyncio.get_running_loop()
+            fut: asyncio.Future[dict] = loop.create_future()
+            try:
+                self._file_upload_waiters[int(video_id)] = fut
+            except Exception:
+                self.logger.exception("Failed to register file upload waiter")
+
+            try:
+                async with ClientSession(
+                    connector=connector, timeout=timeout
+                ) as session:
+                    async with session.post(
+                        url=url,
+                        headers=headers,
+                        data=file_bytes,
+                    ) as response:
+                        if response.status != HTTPStatus.OK:
+                            self.logger.error(
+                                "Upload failed with status %s", response.status
+                            )
+                            self._file_upload_waiters.pop(int(video_id), None)
+                            return None
+
+                        try:
+                            await asyncio.wait_for(fut, timeout=DEFAULT_TIMEOUT)
+                            return Attach(
+                                _type=AttachType.VIDEO, video_id=video_id, token=token
+                            )
+                        except asyncio.TimeoutError:
+                            self.logger.warning(
+                                "Timed out waiting for video processing notification for videoId=%s",
+                                video_id,
+                            )
+                            self._file_upload_waiters.pop(int(video_id), None)
+                            return None
+            except OSError as e:
+                if "malloc failure" in str(e) or "BUF" in str(e):
+                    self.logger.exception(
+                        "Memory error during video upload. File too large or insufficient memory. Try uploading smaller files or free up memory."
+                    )
+                    self._file_upload_waiters.pop(int(video_id), None)
+                raise
+
+        except Exception:
+            self.logger.exception("Upload video failed")
+            raise
 
     async def _upload_photo(self, photo: Photo) -> None | Attach:
         try:
@@ -137,7 +303,7 @@ class MessageMixin(ClientProtocol):
                     data=form,
                 ) as response,
             ):
-                if response.status != 200:
+                if response.status != HTTPStatus.OK:
                     self.logger.error(f"Upload failed with status {response.status}")
                     return None
 
@@ -161,7 +327,7 @@ class MessageMixin(ClientProtocol):
             self.logger.exception("Upload photo failed: %s", str(e))
             return None
 
-    async def _upload_attachment(self, attach: Photo | File) -> dict | None:
+    async def _upload_attachment(self, attach: Photo | File | Video) -> dict | None:
         if isinstance(attach, Photo):
             uploaded = await self._upload_photo(attach)
             if uploaded and uploaded.photo_token:
@@ -174,6 +340,12 @@ class MessageMixin(ClientProtocol):
                 return AttachFilePayload(file_id=uploaded.file_id).model_dump(
                     by_alias=True
                 )
+        elif isinstance(attach, Video):
+            uploaded = await self._upload_video(attach)
+            if uploaded and uploaded.video_id and uploaded.token:
+                return VideoAttachPayload(
+                    video_id=uploaded.video_id, token=uploaded.token
+                ).model_dump(by_alias=True)
         self.logger.error(f"Attachment upload failed for {attach}")
         return None
 
@@ -181,14 +353,32 @@ class MessageMixin(ClientProtocol):
         self,
         text: str,
         chat_id: int,
-        notify: bool,
-        attachment: Photo | File | None = None,
-        attachments: list[Photo | File] | None = None,
+        notify: bool = True,
+        attachment: Photo | File | Video | None = None,
+        attachments: list[Photo | File | Video] | None = None,
         reply_to: int | None = None,
         use_queue: bool = False,
     ) -> Message | None:
         """
-        Отправляет сообщение в чат.
+        Отправляет текстовое сообщение в чат с опциональными вложениями.
+
+        :param text: Текст сообщения.
+        :type text: str
+        :param chat_id: Идентификатор чата, в который отправляется сообщение.
+        :type chat_id: int
+        :param notify: Флаг оповещения о новом сообщении. По умолчанию True.
+        :type notify: bool
+        :param attachment: Одно вложение (фото, файл или видео).
+        :type attachment: Photo | File | Video | None
+        :param attachments: Список множественных вложений.
+        :type attachments: list[Photo | File | Video] | None
+        :param reply_to: Идентификатор сообщения для ответа.
+        :type reply_to: int | None
+        :param use_queue: Использовать очередь для отправки. По умолчанию False.
+        :type use_queue: bool
+        :return: Объект сообщения или None, если используется очередь.
+        :rtype: Message | None
+        :raises Error: Если загрузка вложения или отправка сообщения не удалась.
         """
 
         self.logger.info("Sending message to chat_id=%s notify=%s", chat_id, notify)
@@ -224,9 +414,9 @@ class MessageMixin(ClientProtocol):
 
         elements = []
         clean_text = None
-        raw_elements = Formatting.get_elements_from_markdown(text)[0]
+        raw_elements, parsed_text = Formatting.get_elements_from_markdown(text)
         if raw_elements:
-            clean_text = Formatting.get_elements_from_markdown(text)[1]
+            clean_text = parsed_text
         elements = [
             MessageElement(type=e.type, length=e.length, from_=e.from_)
             for e in raw_elements
@@ -268,10 +458,29 @@ class MessageMixin(ClientProtocol):
         chat_id: int,
         message_id: int,
         text: str,
-        attachment: Photo | None = None,
-        attachments: list[Photo] | None = None,
+        attachment: Photo | File | Video | None = None,
+        attachments: list[Photo | Video | File] | None = None,
         use_queue: bool = False,
     ) -> Message | None:
+        """
+        Редактирует текст и/или вложения существующего сообщения.
+
+        :param chat_id: Идентификатор чата.
+        :type chat_id: int
+        :param message_id: Идентификатор сообщения для редактирования.
+        :type message_id: int
+        :param text: Новый текст сообщения.
+        :type text: str
+        :param attachment: Новое вложение (фото, файл или видео).
+        :type attachment: Photo | File | Video | None
+        :param attachments: Список новых множественных вложений.
+        :type attachments: list[Photo | Video | File] | None
+        :param use_queue: Использовать очередь для отправки.
+        :type use_queue: bool
+        :return: Отредактированное сообщение или None.
+        :rtype: Message | None
+        :raises Error: Если редактирование не удалось.
+        """
         self.logger.info(
             "Editing message chat_id=%s message_id=%s", chat_id, message_id
         )
@@ -351,7 +560,18 @@ class MessageMixin(ClientProtocol):
         use_queue: bool = False,
     ) -> bool:
         """
-        Удаляет сообщения.
+        Удаляет одно или несколько сообщений.
+
+        :param chat_id: Идентификатор чата.
+        :type chat_id: int
+        :param message_ids: Список идентификаторов сообщений для удаления.
+        :type message_ids: list[int]
+        :param for_me: Удалить только для себя (не видимо другим).
+        :type for_me: bool
+        :param use_queue: Использовать очередь для отправки.
+        :type use_queue: bool
+        :return: True, если сообщения успешно удалены.
+        :rtype: bool
         """
         self.logger.info(
             "Deleting messages chat_id=%s ids=%s for_me=%s",
@@ -381,15 +601,16 @@ class MessageMixin(ClientProtocol):
         self, chat_id: int, message_id: int, notify_pin: bool
     ) -> bool:
         """
-        Закрепляет сообщение.
+        Закрепляет сообщение в чате.
 
-        Args:
-            chat_id (int): ID чата
-            message_id (int): ID сообщения
-            notify_pin (bool): Оповещать о закреплении
-
-        Returns:
-            bool: True, если сообщение закреплено
+        :param chat_id: Идентификатор чата.
+        :type chat_id: int
+        :param message_id: Идентификатор сообщения.
+        :type message_id: int
+        :param notify_pin: Отправить уведомление о закреплении.
+        :type notify_pin: bool
+        :return: True, если сообщение успешно закреплено.
+        :rtype: bool
         """
         payload = PinMessagePayload(
             chat_id=chat_id,
@@ -413,7 +634,18 @@ class MessageMixin(ClientProtocol):
         backward: int = 200,
     ) -> list[Message] | None:
         """
-        Получает историю сообщений чата.
+        Получает историю сообщений из чата.
+
+        :param chat_id: Идентификатор чата.
+        :type chat_id: int
+        :param from_time: Временная метка для начала выборки.
+        :type from_time: int | None
+        :param forward: Кол-во сообщений вперед от from_time.
+        :type forward: int
+        :param backward: Кол-во сообщений назад от from_time.
+        :type backward: int
+        :return: Список сообщений или None.
+        :rtype: list[Message] | None
         """
         if from_time is None:
             from_time = int(time.time() * 1000)
@@ -457,15 +689,14 @@ class MessageMixin(ClientProtocol):
         """
         Получает видео
 
-        Args:
-            chat_id (int): ID чата
-            message_id (int): ID сообщения
-            video_id (int): ID видео
-
-        Returns:
-            external (str): Странная ссылка из апи
-            cache (bool): True, если видео кэшировано
-            url (str): Ссылка на видео
+        :param chat_id: ID чата
+        :type chat_id: int
+        :param message_id: ID сообщения
+        :type message_id: int
+        :param video_id: ID видео
+        :type video_id: int
+        :return: Объект VideoRequest или None
+        :rtype: VideoRequest | None
         """
         self.logger.info("Getting video_id=%s message_id=%s", video_id, message_id)
 
@@ -480,7 +711,7 @@ class MessageMixin(ClientProtocol):
                 video_id=video_id,
             ).model_dump(by_alias=True)
 
-            data = await self._send_and_wait(opcode=Opcode.VIDEO_PLAY, payload=payload)
+        data = await self._send_and_wait(opcode=Opcode.VIDEO_PLAY, payload=payload)
 
         if data.get("payload", {}).get("error"):
             MixinsUtils.handle_error(data)
@@ -501,14 +732,14 @@ class MessageMixin(ClientProtocol):
         """
         Получает файл
 
-        Args:
-            chat_id (int): ID чата
-            message_id (int): ID сообщения
-            file_id (int): ID видео
-
-        Returns:
-            unsafe (bool): Проверка файла на безопасность максом
-            url (str): Ссылка на скачивание файла
+        :param chat_id: ID чата
+        :type chat_id: int
+        :param message_id: ID сообщения
+        :type message_id: int
+        :param file_id: ID файла
+        :type file_id: int
+        :return: Объект FileRequest или None
+        :rtype: FileRequest | None
         """
         self.logger.info("Getting file_id=%s message_id=%s", file_id, message_id)
         if self.is_connected and self._socket is not None:
@@ -543,13 +774,14 @@ class MessageMixin(ClientProtocol):
         """
         Добавляет реакцию к сообщению.
 
-        Args:
-            chat_id (int): ID чата
-            message_id (int): ID сообщения
-            reaction (str): Реакция (эмодзи)
-
-        Returns:
-            ReactionInfo | None: Информация о реакции или None при ошибке.
+        :param chat_id: ID чата
+        :type chat_id: int
+        :param message_id: ID сообщения
+        :type message_id: str
+        :param reaction: Реакция для добавления
+        :type reaction: str (emoji)
+        :return: Объект ReactionInfo или None
+        :rtype: ReactionInfo | None
         """
         try:
             self.logger.info(
@@ -588,13 +820,12 @@ class MessageMixin(ClientProtocol):
         """
         Получает реакции на сообщения.
 
-        Args:
-            chat_id (int): ID чата
-            message_ids (list[str]): Список ID сообщений
-
-        Returns:
-            dict[str, ReactionInfo] | None: Словарь с ID сообщений и информацией
-            о реакциях или None при ошибке.
+        :param chat_id: ID чата
+        :type chat_id: int
+        :param message_ids: Список ID сообщений
+        :type message_ids: list[str]
+        :return: Словарь с ID сообщений и соответствующими реакциями
+        :rtype: dict[str, ReactionInfo] | None
         """
         self.logger.info(
             "Getting reactions for messages chat_id=%s message_ids=%s",
@@ -630,12 +861,12 @@ class MessageMixin(ClientProtocol):
         """
         Удаляет реакцию с сообщения.
 
-        Args:
-            chat_id (int): ID чата
-            message_id (str): ID сообщения
-
-        Returns:
-            ReactionInfo | None: Информация о реакции или None при ошибке.
+        :param chat_id: ID чата
+        :type chat_id: int
+        :param message_id: ID сообщения
+        :type message_id: str
+        :return: Объект ReactionInfo или None
+        :rtype: ReactionInfo | None
         """
         self.logger.info(
             "Removing reaction from message chat_id=%s message_id=%s",
