@@ -4,6 +4,8 @@ from pydantic import AliasChoices, BaseModel, Field
 
 from pymax.static.constant import (
     DEFAULT_APP_VERSION,
+    DEFAULT_BUILD_NUMBER,
+    DEFAULT_CLIENT_SESSION_ID,
     DEFAULT_DEVICE_LOCALE,
     DEFAULT_DEVICE_NAME,
     DEFAULT_DEVICE_TYPE,
@@ -73,6 +75,12 @@ class AttachPhotoPayload(CamelModel):
     photo_token: str
 
 
+class VideoAttachPayload(CamelModel):
+    type: AttachType = Field(default=AttachType.VIDEO, alias="_type")
+    video_id: int
+    token: str
+
+
 class AttachFilePayload(CamelModel):
     type: AttachType = Field(default=AttachType.FILE, alias="_type")
     file_id: int
@@ -88,7 +96,7 @@ class SendMessagePayloadMessage(CamelModel):
     text: str
     cid: int
     elements: list[MessageElement]
-    attaches: list[AttachPhotoPayload | AttachFilePayload]
+    attaches: list[AttachPhotoPayload | AttachFilePayload | VideoAttachPayload]
     link: ReplyLink | None = None
 
 
@@ -103,7 +111,7 @@ class EditMessagePayload(CamelModel):
     message_id: int
     text: str
     elements: list[MessageElement]
-    attaches: list[AttachPhotoPayload]
+    attaches: list[AttachPhotoPayload | AttachFilePayload | VideoAttachPayload]
 
 
 class DeleteMessagePayload(CamelModel):
@@ -196,7 +204,7 @@ class ChangeGroupProfilePayload(CamelModel):
 
 class GetGroupMembersPayload(CamelModel):
     type: Literal["MEMBER"] = "MEMBER"
-    marker: int
+    marker: int | None = None
     chat_id: int
     count: int
 
@@ -278,6 +286,8 @@ class UserAgentPayload(CamelModel):
     app_version: str = Field(default=DEFAULT_APP_VERSION)
     screen: str = Field(default=DEFAULT_SCREEN)
     timezone: str = Field(default=DEFAULT_TIMEZONE)
+    client_session_id: int = Field(default=DEFAULT_CLIENT_SESSION_ID)
+    build_number: int = Field(default=DEFAULT_BUILD_NUMBER)
 
 
 class ReworkInviteLinkPayload(CamelModel):
@@ -295,3 +305,38 @@ class RegisterPayload(CamelModel):
     first_name: str
     token: str
     token_type: AuthType = AuthType.REGISTER
+
+
+class CreateFolderPayload(CamelModel):
+    id: str
+    title: str
+    include: list[int]
+    filters: list[Any] = []
+
+
+class GetChatInfoPayload(CamelModel):
+    chat_ids: list[int]
+
+
+class GetFolderPayload(CamelModel):
+    folder_sync: int = 0
+
+
+class UpdateFolderPayload(CamelModel):
+    id: str
+    title: str
+    include: list[int]
+    filters: list[Any] = []
+    options: list[Any] = []
+
+
+class DeleteFolderPayload(CamelModel):
+    folder_ids: list[str]
+
+
+class LeaveChatPayload(CamelModel):
+    chat_id: int
+
+
+class FetchChatsPayload(CamelModel):
+    marker: int
